Credits
=======

The code for the ``generate_subsets()`` function is derived heavily from
`Allen Downey <https://stackoverflow.com/users/661626/allen-downey>`_'s
`Stack Overflow answer <https://stackoverflow.com/a/53726866/1304076>`_.
